# Overview

This section covers advanced topics related to Gato-X.

For installation instructions, see the [Installation Guide](../installation.md).
For command usage, see the [Command Reference](../command-reference/index.md).
For use cases, see the [Use Cases](../use-cases/index.md).


## Available Topics

- [Understanding GitHub Actions Vulnerabilities](vulnerabilities.md) - Detailed explanations of the vulnerability types that Gato-X can identify
- [Complex Attack Scenarios](complex-attacks.md) - Advanced attack techniques and scenarios
